InlineError

Struct InlineError 

pub struct InlineError {
    pub message: String,
    pub span: Option<(usize, usize)>,
    pub annotations: Vec<DiagnosticAnnotation>,
    pub notes: Vec<String>,
    pub helps: Vec<String>,
}
User-facing diagnostic collected during parsing.

Fields

message: String

Primary message for the diagnostic.

span: Option<(usize, usize)>

Primary span, if the diagnostic has one.

annotations: Vec<DiagnosticAnnotation>

Additional annotated spans.

notes: Vec<String>

Explanatory notes.

helps: Vec<String>

Suggested fixes or next steps.

Implementations

Source

impl InlineError

pub fn new(message: impl Into<String>) -> Self

Create a new diagnostic with message and no span.

pub fn at(span: (usize, usize), message: impl Into<String>) -> Self

Create a new diagnostic anchored at span.

pub fn reporting_span(&self) -> (usize, usize)

Span used when reporting (falls back to (0, 0) if unset).

pub fn with_span(self, span: Option<(usize, usize)>) -> Self

Return a copy of this diagnostic with span replaced.

pub fn set_span(&mut self, span: Option<(usize, usize)>) -> &mut Self

Replace the primary span in place.

pub fn with_note(self, note: impl Into<String>) -> Self

Return a copy of this diagnostic with an additional note.

pub fn add_note(&mut self, note: impl Into<String>) -> &mut Self

Add a note in place.

pub fn with_help(self, help: impl Into<String>) -> Self

Return a copy of this diagnostic with an additional help message.

pub fn add_help(&mut self, help: impl Into<String>) -> &mut Self

Add a help message in place.

pub fn with_annotation( self, span: (usize, usize), message: impl Into<String>, kind: AnnotationKind, ) -> Self

Return a copy of this diagnostic with an additional annotation.

pub fn add_annotation( &mut self, span: (usize, usize), message: impl Into<String>, kind: AnnotationKind, ) -> &mut Self

Add an annotation in place.

pub fn eprint(&self, source_id: &str, source_text: &str)

Available on crate feature annotate-snippets only.

Print to stderr (requires annotate-snippets feature).

pub fn write(&self, source_id: &str, source_text: &str, sink: impl Write)

Available on crate feature annotate-snippets only.

Write to sink (requires annotate-snippets feature).