ToParser

Struct ToParser 

pub struct ToParser<Match, Output> { /* private fields */ }
Parser produced by MatcherCombinator::to.

It runs a matcher and returns a fixed output value when the matcher succeeds. The matcher is evaluated with an empty capture result, so this is intended for ordinary matchers, not bind!/bind_span!/bind_slice! capture binders.

Implementations

Source

impl<Match, Output> ToParser<Match, Output>

pub fn new(matcher: Match, output: Output) -> Self

Wrap matcher and return output whenever it succeeds.