pub struct ToParser<Match, Output> { /* private fields */ }Expand description
Parser produced by MatcherCombinator::to.
It runs a matcher and returns a fixed output value when the matcher succeeds.
The matcher is evaluated with an empty capture result, so this is intended for
ordinary matchers, not bind!/bind_span!/bind_slice! capture binders.
Implementations