WithTrace

Trait WithTrace 

pub trait WithTrace
where Self: Sized,
{ // Required methods fn trace(self) -> Traced<Self>; fn trace_with_label(self, label: impl Into<String>) -> Traced<Self>; }
Extension methods for adding explicit trace markers to parsers and matchers.

Required Methods

fn trace(self) -> Traced<Self>

Trace this parser or matcher using its existing label (if any).

fn trace_with_label(self, label: impl Into<String>) -> Traced<Self>

Trace this parser or matcher with an explicit label.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<I> WithTrace for I
where I: Sized,