pub trait WithTracewhere
Self: Sized,{
// Required methods
fn trace(self) -> Traced<Self>;
fn trace_with_label(self, label: impl Into<String>) -> Traced<Self>;
}Expand description
Extension methods for adding explicit trace markers to parsers and matchers.
Required Methods
Sourcefn trace_with_label(self, label: impl Into<String>) -> Traced<Self>
fn trace_with_label(self, label: impl Into<String>) -> Traced<Self>
Trace this parser or matcher with an explicit label.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.